using FitConnect.Services.Models.v1.Destination;

namespace FitConnect.Services.Interfaces;

public interface IDestinationService : IRestCallService {
    /// <summary>
    ///     <para>@PostMapping("/destinations")</para>
    /// </summary>
    /// <param name="createDestination">RequestBody</param>
    /// <returns></returns>
    PrivateDestinationDto CreateDestination(CreateDestinationDto createDestination);

    /// <summary>
    ///     <para>@GetMapping("/destinations/{destinationId}")</para>
    /// </summary>
    /// <param name="destinationId">PathVariable</param>
    void GetDestination(string destinationId);

    /// <summary>
    ///     <para>@DeleteMapping("/destinations/{destinationId}")</para>
    /// </summary>
    /// <param name="destinationId">PathVariable</param>
    /// <returns></returns>
    bool DeleteDestination(string destinationId);

    /// <summary>
    ///     <para>@PatchMapping("/destinations/{destinationId}")</para>
    /// </summary>
    /// <param name="destinationId">PathVariable</param>
    /// <param name="patchDestination">RequestBody</param>
    /// <returns></returns>
    PrivateDestinationDto PatchDestination(string destinationId,
        PatchDestinationDto patchDestination);

    /// <summary>
    ///     <para>@GetMapping("/destinations")</para>
    /// </summary>
    /// <param name="offset">RequestParam</param>
    /// <param name="limit">RequestParam</param>
    /// <returns></returns>
    DestinationListDto ListDestinations(int offset, int limit);

    /// <summary>
    ///     <para>@PutMapping("/destinations/{destinationId}")</para>
    /// </summary>
    /// <param name="destinationId">PathVariable</param>
    /// <param name="updateDestination">RequestBody</param>
    /// <returns></returns>
    PrivateDestinationDto UpdateDestination(string destinationId,
        UpdateDestinationDto updateDestination);

    /// <summary>
    ///     <para>@GetMapping("/v1/destinations/{{destinationId}}/keys/{{keyId}")</para>
    /// </summary>
    /// <param name="destinationId"></param>
    /// <returns></returns>
    Task<string> GetPublicKey(string destinationId);
}
